summaryrefslogtreecommitdiff
path: root/alot/mail/envelope.py
diff options
context:
space:
mode:
Diffstat (limited to 'alot/mail/envelope.py')
-rw-r--r--alot/mail/envelope.py13
1 files changed, 6 insertions, 7 deletions
diff --git a/alot/mail/envelope.py b/alot/mail/envelope.py
index 540c0342..db907340 100644
--- a/alot/mail/envelope.py
+++ b/alot/mail/envelope.py
@@ -14,7 +14,7 @@ from urllib.parse import unquote
import gpg
import magic
-from ..db.attachment import Attachment
+from .attachment import Attachment
from .. import __version__
from .. import helper
from .. import crypto
@@ -99,7 +99,7 @@ class Envelope:
tmpfile = None
"""template text for initial content"""
attachments = None
- """list of :class:`Attachments <alot.db.attachment.Attachment>`"""
+ """list of :class:`Attachments <alot.mail.attachment.Attachment>`"""
tags = None
"""tags to add after successful sendout"""
account = None
@@ -119,7 +119,7 @@ class Envelope:
:param headers: unencoded header values
:type headers: dict (str -> [unicode])
:param attachments: file attachments to include
- :type attachments: list of :class:`~alot.db.attachment.Attachment`
+ :type attachments: list of :class:`~alot.mail.attachment.Attachment`
:param tags: tags to add after successful sendout and saving this msg
:type tags: set of str
:param replied: message being replied to
@@ -231,11 +231,10 @@ class Envelope:
def attach(self, attachment):
"""
- attach a file
+ attach data
- :param attachment: File to attach, given as
- :class:`~alot.db.attachment.Attachment` object
- :type attachment: :class:`~alot.db.attachment.Attachment`
+ :param attachment: data to attach
+ :type attachment: :class:`~alot.mail.attachment.Attachment`
"""
self.attachments.append(attachment)
if self.sent_time: